@@ -502,7 +502,47 @@ static void * __init probe_find_variable(void *function, unsigned long addr,
 	return NULL;
 }
 
-#if defined(LSM_HOOK_INIT)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+
+/**
+ * probe_security_hook_heads - Find address of "struct security_hook_heads security_hook_heads".
+ *
+ * Returns pointer to "struct security_hook_heads" on success, NULL otherwise.
+ */
+struct security_hook_heads * __init probe_security_hook_heads(void)
+{
+	const unsigned int offset = offsetof(struct security_hook_heads,
+					     bprm_committed_creds);
+	void *cp;
+	struct security_hook_heads *shh;
+	struct security_hook_list *entry;
+	void *cap = probe_find_symbol(" cap_bprm_creds_from_file\n");
+
+	/* Get location of cap_bprm_set_creds(). */
+	cap = check_function_address(cap, "cap_bprm_creds_from_file");
+	if (!cap)
+		return NULL;
+	/* Guess "struct security_hook_heads security_hook_heads;". */
+	cp = probe_find_variable(probe_security_bprm_committed_creds,
+				 ((unsigned long)
+				  &probe_dummy_security_hook_heads) + offset,
+				 " security_bprm_committed_creds\n");
+	if (!cp) {
+		printk(KERN_ERR
+		       "Can't resolve security_bprm_committed_creds().\n");
+		return NULL;
+	}
+	/* This should be "struct security_hook_heads security_hook_heads;". */
+	shh = ((void *) (*(unsigned long *) cp)) - offset;
+	hlist_for_each_entry(entry, &shh->bprm_creds_from_file, list)
+		if (entry->hook.bprm_creds_from_file == cap)
+			return shh;
+	printk(KERN_ERR "Guessed security_hook_heads is 0x%lx\n",
+	       (unsigned long) shh);
+	return NULL;
+}
+
+#elif defined(LSM_HOOK_INIT)
 
 /**
  * probe_security_hook_heads - Find address of "struct security_hook_heads security_hook_heads".
